@@ -40,7 +40,7 @@ use vars qw(@ISA @EXPORT);
 
 use PDL::Doc;
 use IO::File;
-use Pod::Text;
+use Pod::PlainText;
 
 $PDL::onlinedoc = undef;
 $PDL::onlinedoc = new PDL::Doc (FindStdFile());
@@ -48,23 +48,6 @@ $PDL::onlinedoc = new PDL::Doc (FindStdFile());
 use PDL::Config;
 my $bvalflag = $PDL::Config{WITH_BADVAL} || 0;
 
-# pod commands are stripped from the ref string before printing.
-# How we do this depends on the version of Pod::Text installed.
-#
-# I'm guessing the difference in behaviour is between versions
-# 1 and 2 of Pod::Text (it's certainly true for 
-# version 1.0203 (perl5.005_03) and 2.03 (perl 5.6.0))
-#
-# version 1:
-#  we use a private routine from Pod::Text
-#  (prepare_for_output) in printmatch() in order
-#  to strip away pod directives from the ref
-#  string
-#
-# version 2: (Thanks to Tim Jenness)
-#  create an object and use the interpol() method
-#
-
 # Find std file
 
 sub FindStdFile {
@@ -97,9 +80,6 @@ sub screen_width() {
        || 72;
 }
 
-# the $^W assignment stops Pod::Text::fill() from 
-# generating "Use of uninitialised values" errors
-#
 sub printmatch {
     my @match = @_;
     if (@match) {
@@ -113,58 +93,34 @@ sub printmatch {
 # for the given matches
 #
 sub format_ref {
-    my @match = @_;
-    my @text = ();
+  my @match = @_;
+  my @text = ();
 
-    # XXX this is NASTY
-    my $width = screen_width()-17;
-    if ( $Pod::Text::VERSION < 2 ) {
-	$Pod::Text::indent = 0;
-	$Pod::Text::SCREEN = $width;
-	local $^W = 0;
-	for my $m (@match) { 
-	    $_ = $m->[1]{Ref} || 
-		( (defined $m->[1]{CustomFile})
-		  ? "[No ref avail. for `".$m->[1]{CustomFile}."']"
-		  : "[No reference available]"
-		  );
-	  Pod::Text::prepare_for_output(); # adds a '\n' to $_
-	    $_ = Pod::Text::fill $_; # try and get `nice' wrapping 
-	    s/\n*$//; # remove last new lines (so substitution doesn't append spaces at end of text)
-	    s/\n/\n                /g;
-	    my $name = $m->[0];
-	    if ( length($name) > 15 ) { 
-	        push @text, sprintf "%s ...\n                %s\n", $name, $_; 
-	    } else {
-		push @text, sprintf "%-15s %s\n", $name, $_; 
-	    }
-	}
+  my $width = screen_width()-17;
+  my $parser = new Pod::PlainText( width => $width, indent => 0, sentence => 0 );
+
+  for my $m (@match) { 
+    my $ref = $m->[1]{Ref} || 
+      ( (defined $m->[1]{CustomFile})
+        ? "[No ref avail. for `".$m->[1]{CustomFile}."']"
+        : "[No reference available]"
+     );
+
+    $ref = $parser->interpolate( $ref );
+    $ref = $parser->reformat( $ref );
+
+    # remove last new lines (so substitution doesn't append spaces at end of text)
+    $ref =~ s/\n*$//;
+    $ref =~ s/\n/\n                /g;
+
+    my $name = $m->[0];
+    if ( length($name) > 15 ) { 
+      push @text, sprintf "%s ...\n                %s\n", $name, $ref;
     } else {
-	my $parser = new Pod::Text( width => $width, indent => 0, sentence => 0 );
-	
-	for my $m (@match) { 
-	    my $ref = $m->[1]{Ref} || 
-		( (defined $m->[1]{CustomFile})
-		  ? "[No ref avail. for `".$m->[1]{CustomFile}."']"
-		  : "[No reference available]"
-		  );
-
-	    $ref = $parser->interpolate( $ref );
-	    $ref = $parser->reformat( $ref );
-	    
-	    # remove last new lines (so substitution doesn't append spaces at end of text)
-	    $ref =~ s/\n*$//; 
-	    $ref =~ s/\n/\n                /g;
-
-	    my $name = $m->[0];
-	    if ( length($name) > 15 ) { 
-		push @text, sprintf "%s ...\n                %s\n", $name, $ref; 
-	    } else {
-		push @text, sprintf "%-15s %s\n", $name, $ref; 
-	    }
-	}
+      push @text, sprintf "%-15s %s\n", $name, $ref;
     }
-    return wantarray ? @text : $text[0];
+  }
+  return wantarray ? @text : $text[0];
 
 } # sub: format_ref()
 
@@ -245,57 +201,75 @@ Internal interface to the PDL documentation searcher
 =cut
 
 sub finddoc  {
+    local $SIG{PIPE}= sub {}; # Prevent crashing if user exits the pager
+
     die 'Usage: doc $topic' unless $#_>-1;
     die "no online doc database" unless defined $PDL::onlinedoc;
     my $topic = shift;
 
     # See if it matches a PDL function name
 
+    my $subfield = $1
+      if( $topic =~ s/\[(\d*)\]$// );
+
     (my $t2 = $topic) =~ s/([^a-zA-Z0-9_])/\\$1/g;  
 
     my @match = search_docs("m/^(PDL::)?".$t2."\$/",['Name'],0);
 
-
     unless(@match) {
       
-      print "Unable to find PDL docs on '$topic' -- using whatis instead...\n\n";
+      print "No PDL docs for '$topic'. Using 'whatis'. (Try 'apropos $topic'?)\n\n";
       whatis($topic);
       return;
 
     }
 
     # print out the matches
-    # - do not like this solution when have multiple matches
-    #   but looping through each match didn't seem right either
+
+    my $out = IO::File->new( "| pod2text | $PDL::Doc::pager" );
+    
+    if($subfield) {
+      if($subfield <= @match) {
+	@match = ($match[$subfield-1]);
+	$subfield = 0;
+      } else {
+	print $out "\n\n=head1 PDL HELP: Ignoring out-of-range selector $subfield\n\n=head1\n\n=head1 --------------------------------\n\n";
+	$subfield = undef;
+      }
+    }
+    
+    if (  @match > 1   and   !$subfield  ) {
+      print $out "\n\n=head1 MULTIPLE MATCHES FOR HELP TOPIC '$topic':\n\n=head1\n\n=over 3\n\n";
+      my $i=0;
+      for my $m ( @match ) {
+	printf $out "\n=item [%d]\t%-30s %s%s\n\n", ++$i, $m->[0], $m->[1]{Module} && "in ", $m->[1]{CustomFile} || $m->[1]{Module};
+      }
+      print $out "\n=back\n\n=head1\n\n To see item number \$n, use 'help ${topic}\[\$n\]'. \n\n=head1 Displaying item 1:\n\n=head1 --------------------------------------\n\n=cut\n\n";
+    }
+    
     my $m = shift @match;
+    
     my $Ref = $m->[1]{Ref};
     if ( $Ref =~ /^(Module|Manual|Script): / ) {
-	system("pod2text $m->[1]{File} | $PDL::Doc::pager");
+      my $in = IO::File->new("<$m->[1]{File}");
+      print $out join("",<$in>);
     } else {
-	my $out = IO::File->new( "| pod2text | $PDL::Doc::pager" );
-
-	if(defined $m->[1]{CustomFile}) {
-
-	    my $parser= new PDL::Pod::Parser;
-	    print $out "=head1 Autoload file \"".$m->[1]{CustomFile}."\"\n\n";
-	    $parser->parse_from_file($m->[1]{CustomFile},$out);
-	    print $out "\n\n=head2 Docs from\n\n".$m->[1]{CustomFile}."\n\n";
-
-	} else {
-
-	    print $out "=head1 Module ",$m->[1]{Module}, "\n\n";
-	    $PDL::onlinedoc->funcdocs($m->[0],$out);
-
-	}
-
+      if(defined $m->[1]{CustomFile}) {
+	
+	my $parser= new PDL::Pod::Parser;
+	print $out "=head1 Autoload file \"".$m->[1]{CustomFile}."\"\n\n";
+	$parser->parse_from_file($m->[1]{CustomFile},$out);
+	print $out "\n\n=head2 Docs from\n\n".$m->[1]{CustomFile}."\n\n";
+	
+      } else {
+	
+	print $out "=head1 Module ",$m->[1]{Module}, "\n\n";
+	$PDL::onlinedoc->funcdocs($m->[0],$out);
+	
+      }
+      
     }
-    if ( $#match > -1 ) {
-	print "\nFound other matches for $topic:\n";
-	foreach my $m ( @match ) {
-	    printf "  %-30s in %s\n", $m->[0], $m->[1]{Module};
-	}
-    }
-}
+  }
 
 
 =head2 find_autodoc
